@@ -1,3 +1,5 @@
+import sys
+
 import streamlit as st
 import os
 from api.generator import API
@@ -22,13 +24,14 @@ def display_result(api_instance, syntax):
                         locust_file.write(str(syntax))
                         locust_file.close()
                         st.write(f'Folder Location: {path}/{file_name}.py')
+
             else:
                 save = st.checkbox(label='Save Python Syntax')
                 if save:
                     if api_instance[0].performance:
-                        path = f'{api_instance[2]}/locust_run.py'
+                        path = f'{api_instance[2]}\\locust_run.py'
                     else:
-                        path = f'{api_instance[2]}/api_run.py'
+                        path = f'{api_instance[2]}\\api_run.py'
 
                     with open(path, 'w') as locust_file:
                         locust_file.write(str(syntax))
@@ -70,7 +73,7 @@ def set_port(domain):
 
 def prepare_data(api_instance):
     # TODO: add description
-    domain = st.text_input('Domain / Host: ')
+    domain = st.text_input(label='Domain / Host:')
     st.container()
     if len(domain) > 0:
         port = set_port(domain=domain)
@@ -79,6 +82,7 @@ def prepare_data(api_instance):
     params = None
     headers = None
     body = None
+    expected_status_code = None
     count = 1
     services_data = []
     """ start to create html containers """
@@ -89,7 +93,7 @@ def prepare_data(api_instance):
                                   options=('GET', 'POST', 'PUT', 'DELETE', 'PATCH'))
 
             """ set api resource """
-            resource = st.text_input(f'Resource service ({count}) ')
+            resource = st.text_input(f'Resource / Route service ({count}) ')
 
             """ set api parameters """
             params_cb = st.checkbox(label=f'Params service ({count}): ')
@@ -121,7 +125,12 @@ def prepare_data(api_instance):
                     st.write('Your body object is: ')
                     st.json(body)
             """ add results the services data list """
-            services_data.insert(count - 1, (method, resource, params, headers, body, count))
+
+            if not api_instance[0].performance:
+                expected_status_code = st.text_input(f'Expected Status Code service ({count}):')
+                if len(expected_status_code) <= 2:
+                    st.error(f'Please add expected status code in service ({count})')
+            services_data.insert(count - 1, (method, resource, params, headers, body, count, expected_status_code))
         count += 1
 
     code = show_syntax(api_instance, domain, port, services_data)
@@ -146,7 +155,8 @@ def show_syntax(api_instance, domain, port, services_data):
                 code += api_instance[0].set_method(method=method, resource=service[1],
                                                    params=service[2],
                                                    headers=service[3],
-                                                   body=service[4], name=name, domain=f"{domain}:{port}")
+                                                   body=service[4], name=name, domain=f"{domain}:{port}",
+                                                   expected_status_code=service[6])
         if not api_instance[0].performance:
             return f"{code}{api_instance[0].expected_status_code_method}"
 
@@ -157,8 +167,10 @@ def show_syntax(api_instance, domain, port, services_data):
 def run_script(res_obj, api_instance):
     # TODO: add description
     if res_obj[0]:
-        run = st.button('Run Script')
-        if run:
+        run_time = st.text_input(label="Run Time in Seconds (use only in command-line mode)")
+        run_web_ui = st.button('Run Script in Web-UI')
+        run_headless = st.button('Run Script in Command Line')
+        if run_web_ui:
             if api_instance[0].performance:
                 """ create locust performance ui """
                 host = res_obj[1]
@@ -174,6 +186,16 @@ def run_script(res_obj, api_instance):
                 os.system(f'py.test api_run.py --alluredir=tmp/allure_results')
                 st.markdown("2. Finish with success...")
                 os.system(f'allure serve tmp/allure_results')
+                os.system(f'close')
+
+        elif run_headless:
+            if api_instance[0].performance:
+                """ create locust performance ui """
+                host = res_obj[1]
+                if len(res_obj) > 0:
+                    host += f":{res_obj[2]}"
+                    st.write("Your App start, Look at your command-line")
+                    os.system(f'locust -f locust_run.py --headless --host={host} -t {run_time}')
 
 
 def run_app(main_path):
